.. currentmodule:: tibs

API
---

The API docs are generated from the docs strings, so are also available via the ``help()``
function in a Python interpreted session.

The two classes available in the tibs module are:

* :class:`Tibs` An immutable sequence of bits.
* :class:`Mutibs` A mutable sequence of bits.

.. toctree::
    :maxdepth: 1
    :hidden:

    tibs
    mutibs